==> wikipeople-0.3-py2.py3-none-any.whl: wikipeople/wikipeople.py <==
"""
    @author: svanstroud
    Get information about people using the wikidata API
"""

import requests 



def search_wikidata(string):
  """
  Query the Wikidata API using the wbsearchentities function.
  Return the concept ID of the first search result.
  """

  query = 'https://www.wikidata.org/w/api.php?action=wbsearchentities&search='
  query += string
  query += '&language=en&format=json'

  res = requests.get(query).json()

  if len(res['search']) == 0:
    raise Exception('Wikidata search failed.')

  return res['search'][0]['id']


def get_concept_id_from_url(url):
    """
    Given a wikipedia URL, find the corresponding wikidata
    concept ID for the page.
    """
    
    # assume the page title follows the final slash (not always valid)
    page_title = url.split('/')[-1]
    
    # setup query
    query = 'https://en.wikipedia.org/w/api.php?action=query&prop=pageprops&titles='
    query += page_title
    query += '&format=json'
    
    # make the request
    res = requests.get(query).json()
    res = list(res['query']['pages'].values())[0]
    
    # check result
    try:
      concept_id = res['pageprops']['wikibase_item']
    except:
      concept_id = 'NA'

    return concept_id


def get_concept_label(concept_id):
  """
  Given a concept ID, get the natural language label.
  """
  query = 'https://www.wikidata.org/w/api.php?action=wbgetentities&ids='
  query += concept_id
  query += '&format=json&languages=en&props=labels'

  res = requests.get(query).json()
  try:
    label = res['entities'][concept_id]['labels']['en']['value']
  except:
    label = 'NA'

  return label


def get_property(concept_id, property_id):
  """
  Properties:
   - P569 = Date of birth
   - P106 = Career
   - Place of birth (P19)
   - Country of citizenship (P27)
   - Sex or Gender (P21)
  Get the concept ID for a property associated to an input concept.
  """

  query = 'https://www.wikidata.org/w/api.php?action=wbgetclaims&entity='
  query += concept_id
  query += '&property='+property_id+'&language=en&format=json'

  res = requests.get(query).json()

  try:
    for prop in res['claims'][property_id]:
      concept_result = prop['mainsnak']['datavalue']['value']['id']
      break # just get the first result for now
  except:
    concept_result = 'NA'

  try:
    concept_label = get_concept_label(concept_result)
  except: 
    concept_label = 'NA'
  
  return concept_result, concept_label


def get_date_of_birth(concept_id):
  """
  Properties:
   - P569 = Date of birth
  Get a person's DOB given their concept. This gets it's own function
  as the structure of the result is slightly different.
  """

  property_id = 'P569'

  query = 'https://www.wikidata.org/w/api.php?action=wbgetclaims&entity='
  query += concept_id
  query += '&property='+property_id+'&language=en&format=json'

  res = requests.get(query).json()

  try:
    for prop in res['claims'][property_id]:
      concept_result = prop['mainsnak']['datavalue']['value']['time'].split('T')[0]
      break
  except:
    concept_result = 'NA'
  
  return concept_result


def get_parent_class(profession_concept_id):
  """
  Given a profession concept ID, find the parent profession.
  """

  property_id = 'P279' # "is subclass of"

  query = 'https://www.wikidata.org/w/api.php?action=wbgetclaims&entity='
  query += profession_concept_id
  query += '&property='+property_id+'&format=json'

  res = requests.get(query).json()

  try:
    for claim in res['claims'][property_id]:
      parent_concept = claim['mainsnak']['datavalue']['value']['id']
      break # just use the first result for now
  except:
    parent_concept = 'NA'

  try:
    parent_concept_label = get_concept_label(parent_concept)
  except:
    parent_concept_label = 'NA'

  return parent_concept, parent_concept_label


def get_profession_hierarchy(castaway_concept_id):
  person_concept_id = 'Q215627' # we don't need to go further than this

  # get the persons profession
  concept_id, label = get_property(castaway_concept_id, 'P106')
  if concept_id == label == 'NA':
    return []

  # store the first progression we get
  hierarchy = [label]

  # while we didn't reach the top
  while True:
    
    # get the parent profession of the current profession
    concept_id, label = get_parent_class(concept_id)
    
    # if the parent is the person conept, we are done
    if concept_id == person_concept_id:
      break

    # otherwise store this profession and go again
    hierarchy.append(label)

  return hierarchy


def get_country(place_concept_id):
  """
  Given a place concept ID, find the Country which this place is in.
  """

  property_id = 'P17' # "Country"

  query = 'https://www.wikidata.org/w/api.php?action=wbgetclaims&entity='
  query += place_concept_id
  query += '&property='+property_id+'&format=json'

  res = requests.get(query).json()

  try:
    for claim in res['claims'][property_id]:
      parent_concept = claim['mainsnak']['datavalue']['value']['id']
      break # just use the first result for now
  except:
    parent_concept = 'NA'
  
  try:
    parent_concept_label = get_concept_label(parent_concept)
  except:
    parent_concept_label = 'NA'


  return parent_concept, parent_concept_label

==> wikipeople-0.4-py2.py3-none-any.whl: wikipeople/wikipeople.py <==
"""
    @author: svanstroud
    Get information about people using the wikidata API
"""

import requests 



def search_wikidata(string):
  """
  Query the Wikidata API using the wbsearchentities function.
  Return the concept ID of the first search result.
  """

  query = 'https://www.wikidata.org/w/api.php?action=wbsearchentities&search='
  query += string
  query += '&language=en&format=json'

  res = requests.get(query).json()

  if len(res['search']) == 0:
    raise Exception('Wikidata search failed.')

  return res['search'][0]['id']


def get_concept_id_from_url(url):
    """
    Given a wikipedia URL, find the corresponding wikidata
    concept ID for the page.
    """
    
    # assume the page title follows the final slash (not always valid)
    page_title = url.split('/')[-1]
    
    # setup query
    query = 'https://en.wikipedia.org/w/api.php?action=query&prop=pageprops&titles='
    query += page_title
    query += '&format=json'
    
    # make the request
    res = requests.get(query).json()
    res = list(res['query']['pages'].values())[0]
    
    # check result
    try:
      concept_id = res['pageprops']['wikibase_item']
    except:
      concept_id = 'NA'

    return concept_id


def get_concept_label(concept_id):
  """
  Given a concept ID, get the natural language label.
  """
  query = 'https://www.wikidata.org/w/api.php?action=wbgetentities&ids='
  query += concept_id
  query += '&format=json&languages=en&props=labels'

  res = requests.get(query).json()
  try:
    label = res['entities'][concept_id]['labels']['en']['value']
  except:
    label = 'NA'

  return label


def get_property(concept_id, property_id):
  """
  Properties:
   - P569 = Date of birth
   - P106 = Career
   - Place of birth (P19)
   - Country of citizenship (P27)
   - Sex or Gender (P21)
  Get the concept ID for a property associated to an input concept.
  """

  query = 'https://www.wikidata.org/w/api.php?action=wbgetclaims&entity='
  query += concept_id
  query += '&property='+property_id+'&language=en&format=json'

  res = requests.get(query).json()

  try:
    for prop in res['claims'][property_id]:
      concept_result = prop['mainsnak']['datavalue']['value']['id']
      break # just get the first result for now
  except:
    concept_result = 'NA'

  try:
    concept_label = get_concept_label(concept_result)
  except: 
    concept_label = 'NA'
  
  return concept_result, concept_label


def get_date_of_birth(concept_id):
  """
  Properties:
   - P569 = Date of birth
  Get a person's DOB given their concept. This gets it's own function
  as the structure of the result is slightly different.
  """

  property_id = 'P569'

  query = 'https://www.wikidata.org/w/api.php?action=wbgetclaims&entity='
  query += concept_id
  query += '&property='+property_id+'&language=en&format=json'

  res = requests.get(query).json()

  try:
    for prop in res['claims'][property_id]:
      concept_result = prop['mainsnak']['datavalue']['value']['time'].split('T')[0]
      break
  except:
    concept_result = 'NA'
  
  return concept_result


def get_parent_class(profession_concept_id):
  """
  Given a profession concept ID, find the parent profession.
  """

  property_id = 'P279' # "is subclass of"

  query = 'https://www.wikidata.org/w/api.php?action=wbgetclaims&entity='
  query += profession_concept_id
  query += '&property='+property_id+'&format=json'

  res = requests.get(query).json()

  try:
    for claim in res['claims'][property_id]:
      parent_concept = claim['mainsnak']['datavalue']['value']['id']
      break # just use the first result for now
  except:
    parent_concept = 'NA'

  try:
    parent_concept_label = get_concept_label(parent_concept)
  except:
    parent_concept_label = 'NA'

  return parent_concept, parent_concept_label


def get_profession_hierarchy(castaway_concept_id):
  person_concept_id = 'Q215627' # we don't need to go further than this

  # get the persons profession
  concept_id, label = get_property(castaway_concept_id, 'P106')
  if concept_id == label == 'NA':
    return []

  # store the first progression we get
  hierarchy = [label]

  # while we didn't reach the top
  while True:

    # get the parent profession of the current profession
    concept_id, label = get_parent_class(concept_id)

    # if the parent is the person conept, we are done
    if concept_id == person_concept_id or label == 'NA':
      break

    # otherwise store this profession and go again
    hierarchy.append(label)

  return hierarchy


def get_country(place_concept_id):
  """
  Given a place concept ID, find the Country which this place is in.
  """

  property_id = 'P17' # "Country"

  query = 'https://www.wikidata.org/w/api.php?action=wbgetclaims&entity='
  query += place_concept_id
  query += '&property='+property_id+'&format=json'

  res = requests.get(query).json()

  try:
    for claim in res['claims'][property_id]:
      parent_concept = claim['mainsnak']['datavalue']['value']['id']
      break # just use the first result for now
  except:
    parent_concept = 'NA'
  
  try:
    parent_concept_label = get_concept_label(parent_concept)
  except:
    parent_concept_label = 'NA'


  return parent_concept, parent_concept_label
